==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=sk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'Zobraziť v poliach',
	'affichage_documents_en_grand' => 'Zobraziť plnú veľkosť',
	'affichage_documents_en_liste_compacte' => 'Zobraziť ako kompaktný zoznam',
	'aucun_audio' => 'Žiadna zvuková stopa',
	'aucun_document' => 'Žiaden dokument',
	'aucun_file' => 'Žiaden dokument',
	'aucun_image' => 'Žiaden obrázok',
	'aucun_video' => 'Žiadne videá',
	'aucune_utilisation' => 'Tento dokument sa nepoužíva.',
	'aucune_vignette' => 'Žiadna miniatúra',

	// B
	'bouton_ajouter_document' => 'Pridať dokument',
	'bouton_ajouter_image' => 'Pridať obrázok',
	'bouton_ajouter_image_document' => 'Pridať obrázok alebo dokument',
	'bouton_attacher_document' => 'Pripojiť',
	'bouton_copier_local' => 'Skopírovať na stránku',
	'bouton_download_depuis' => 'z(o):',
	'bouton_download_local' => 'môjho počítača',
	'bouton_download_par_ftp' => 'servera',
	'bouton_download_par_mediatheque' => 'do knižnice multimédií',
	'bouton_download_sur_le_web' => 'internetu',
	'bouton_enlever_document' => 'Zrušiť prepojenie',
	'bouton_enlever_supprimer_document' => 'Odstrániť',
	'bouton_enlever_supprimer_document_confirmation' => 'Chcete odstrániť dokument?',
	'bouton_modifier_document' => 'Upraviť',
	'bouton_parcourir' => 'Prehľadať...',
	'bouton_refresh_document' => 'Obnoviť dokument',
	'bouton_remplacer_document' => 'Nahradiť tento dokument',
	'bouton_remplacer_image' => 'Nahradiť tento obrázok',
	'bouton_remplacer_image_document' => 'Nahradiť obrázkom alebo dokumentom',
	'bouton_supprimer' => 'Odstrániť',
	'bouton_supprimer_tous_orphelins' => 'Odstrániť všetky nepoužívané', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Určite chcete odstrániť @nb@ osamotených objektov?', # MODIF
	'bouton_upload' => 'Nahrať',

	// D
	'des_audios' => '@nb@ zvukových stôp',
	'des_documents' => '@nb@ dokumentov',
	'des_files' => '@nb@ súborov',
	'des_images' => '@nb@ obrázkov',
	'des_utilisations' => '@nb@ použití',
	'des_videos' => '@nb@ videosekvencií',
	'descriptif' => 'Opis',
	'details_document' => 'Podrobnosti',
	'details_document_afficher_masquer' => 'Zobraziť/skryť podrobnosti dokumentu',
	'document_attache_succes' => 'Dokument bol úspešne pridaný',
	'document_copie_locale_succes' => 'Súbor bol úspešne skopírovaný na stránku',
	'document_installe_succes' => 'Súbor sa úspešne nahral',
	'document_vu' => 'Vložiť do textu',
	'documents' => 'Knižnica multimédií',
	'documents_brises' => 'Pokazené',
	'documents_distants' => 'Vzdialené',
	'documents_locaux' => 'Miestne',
	'documents_non_publies' => 'Nepublikované',
	'documents_orphelins' => 'Nepoužívané',
	'documents_publies' => 'Publikované',
	'documents_tous' => 'Všetky',
	'double_clic_inserer_doc' => 'Ak chcete do textu vložiť túto klávesovú skratku, dvakrát kliknite',

	// E
	'entree_dimensions' => 'Veľkosť:',
	'entree_titre_document' => 'Názov dokumentu:',
	'entree_titre_image' => 'Názov obrázka:',
	'erreur_aucun_document' => 'Tento dokument v knižnici multimédií neexistuje',
	'erreur_aucun_fichier' => 'Žiaden súbor sa nenašiel',
	'erreur_autorisation' => 'Autorizácia sa nepodarila.',
	'erreur_chemin_distant' => 'Nepodarilo sa nájsť vzdialený súbor @nom@',
	'erreur_chemin_ftp' => 'Uvedený súbor sa na serveri nenašiel',
	'erreur_copie_fichier' => 'Nepodarilo sa skopírovať súbor @nom@',
	'erreur_dossier_tmp_manquant' => 'V dočasnom priečinku chýbajú súbory na stiahnutie',
	'erreur_ecriture_fichier' => 'Chyba pri zápise súboru na disk',
	'erreur_format_fichier_image' => 'Formát súboru @nom@ nie je vhodný pre obrázok',
	'erreur_indiquez_un_fichier' => 'Uveďte súbor!',
	'erreur_insertion_document_base' => 'Dokument @fichier@ sa nepodarilo uložiť do databázy súborov',
	'erreur_objet_absent' => 'Prijaté údaje nie sú kompletné.',
	'erreur_suppression_vignette' => 'Chyba pri odstraňovaní miniatúry',
	'erreur_upload_type_interdit' => 'Sťahovanie súborov typu @nom@ nie je povolené',
	'erreur_upload_vignette' => 'Chyba pri načítavaní miniatúry @nom@',
	'erreurs' => '@nb@ chýb',
	'erreurs_voir' => 'Pozrite sa na @nb@ chýb',

	// F
	'fichier_distant' => 'Vzdialený súbor',
	'fichier_manquant' => 'Chýbajúci súbor',
	'fichier_modifie' => 'Súbor bol zmenený. Kliknite na tlačidlo Uložiť.',
	'format_date_incorrect' => 'Dátum alebo čas nie je správny',

	// I
	'icone_creer_document' => 'Pridať dokument',
	'id' => 'ID',
	'image_tourner_180' => 'Otočiť o 180°',
	'image_tourner_droite' => 'Otočiť o 90° doprava',
	'image_tourner_gauche' => 'Otočiť o 90° doľava',
	'info_dimensions_image' => 'Rozmery',
	'info_doc_max_poids' => 'Dokumenty musia mať nevyhnutne menej ako @maxi@ (tento súbor má @actuel@).',
	'info_document' => 'Dokument',
	'info_document_indisponible' => 'Tento dokument je nedostupný',
	'info_documents' => 'Dokumenty',
	'info_duree' => 'Trvanie',
	'info_gauche_numero_document' => 'DOKUMENT ČÍSLO',
	'info_hauteur' => 'Výška',
	'info_heure' => 'Čas',
	'info_illustrations' => 'Ilustrácie',
	'info_image_max_poids' => 'Obrázky musia mať nevyhnutne menej ako @maxi@ (tento súbor má @actuel@).',
	'info_image_max_taille' => 'Obrázky musia mať nevyhnutne menej ako @maxi@ (tento súbor má @actuel@).',
	'info_inclusion_directe' => 'Priame zaradenie:',
	'info_inclusion_vignette' => 'Zaradiť miniatúru:',
	'info_installer_tous_documents' => 'Nainštalovať všetky dokumenty',
	'info_largeur' => 'Šírka',
	'info_logo_max_taille' => 'Logá musia mať menej ako @maxi@ (tento súbor má @actuel@).',
	'info_mode' => 'Režim',
	'info_modifier_document' => 'Upraviť dokument',
	'info_portfolio' => 'Portfólio',
	'info_referencer_doc_distant' => 'Odkázať na dokument na internete:',
	'info_resolution_image' => 'Rozlíšenie',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Žiadna miniatúra',
	'info_statut_document' => 'Tento dokument je:',
	'info_taille' => 'Veľkosť',
	'info_telecharger' => 'Nahrať z vášho počítača:',
	'infos' => 'Technické údaje',
	'item_autoriser_selectionner_date_en_ligne' => 'Povoliť zmeniť dátum každého dokumentu',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Dátum dokumentu je deň, keď bol pridaný na stránku',

	// L
	'label_activer_document_objets' => 'Aktivovať nahrávanie pre obsah:',
	'label_apercu' => 'Ukážka',
	'label_caracteristiques' => 'Funkcie',
	'label_credits' => 'Autori',
	'label_fichier' => 'Súbor',
	'label_fichier_vignette' => 'Miniatúra',
	'label_paginer_par' => 'Stránkovať po:',
	'label_parents' => 'Tento dokument je prepojený s prvkom',
	'label_refdoc_joindre' => 'Dokument číslo',
	'lien_tout_desordonner' => 'Obnoviť poradie',
	'lien_tout_desordonner_verif' => 'Poradie určené pre tento zoznam dokumentov sa zmení. Určite to chcete urobiť?',
	'lien_tout_enlever' => 'Odstrániť všetko', # MODIF
	'logo' => 'Logo',

	// M
	'media_audio' => 'Zvukové stopy',
	'media_file' => 'Ostatné',
	'media_image' => 'Obrázky',
	'media_video' => 'Videá',
	'miniature_automatique_active' => 'SPIP automaticky vytvorí miniatúru obrázka',

	// N
	'nb_documents_attache_succes' => '@nb@ dokumentov bolo pridaných',
	'nb_documents_installe_succes' => '@nb@ súborov sa úspešne nahralo',

	// O
	'objet_document' => 'Dokument',
	'objet_documents' => 'Dokumenty',
	'ordonner_ce_document' => 'Zoradiť tento dokument',

	// P
	'par_date' => 'Dátum',
	'par_hauteur' => 'Výška',
	'par_id' => 'ID',
	'par_largeur' => 'Šírka',
	'par_taille' => 'Veľkosť',
	'par_titre' => 'Názov',

	// T
	'texte_documents_joints' => 'Môžete aktivovať rozhranie na pridávanie dokumentov (súborov z práce, obrázkov
 multimédiálnych súborov, atď.) k článkom, rubrikám a inde. Na tieto súbory
 môžete potom 
v článku odkazovať alebo môžu byť zobrazené samostatne.',
	'texte_documents_joints_2' => 'Toto nastavenie nezabráni priamemu vkladaniu obrázkov do článkov alebo pripojeniu súboru priamo do textu redakčného objektu.',
	'titre_documents_joints' => 'Pripojené dokumenty',
	'titre_page_documents_edit' => 'Upraviť dokument: @titre@',
	'tous_les_medias' => 'Všetky multimédiá',
	'tout_dossier_upload' => 'Celý priečinok @upload@',
	'tout_voir' => 'Zobraziť všetko',

	// U
	'un_audio' => '1 zvuková stopa',
	'un_document' => '1 dokument',
	'un_file' => '1 súbor',
	'un_image' => '1 obrázok',
	'un_video' => '1 video',
	'une_utilisation' => '1 použitie',
	'upload_fichier_zip' => 'Súbor ZIP',
	'upload_fichier_zip_texte' => 'Súbor, ktorý sa chcete nainštalovať, je súbor ZIP.',
	'upload_fichier_zip_texte2' => 'Tento súbor môže byť:',
	'upload_info_mode_document' => 'Poslať do portfólia',
	'upload_info_mode_image' => 'Odstrániť z portfólia',
	'upload_limit' => 'Tento súbor je pre server príliš veľký, maximálna povolená veľkosť na <i>nahrávanie</i> je @max@.',
	'upload_zip_conserver' => 'Ponechať si súbor archívu aj po rozbalení jeho obsahu',
	'upload_zip_decompacter' => 'rozbalený a každý súbor, ktorý obsahuje, bude nainštalovaný na stránku. Nainštalované budú tieto súbory:',
	'upload_zip_mode_document' => 'Všetky obrázky zaradiť do portfólia',
	'upload_zip_telquel' => 'nainštalovaný tak, ako je, ako súbor ZIP,',
	'upload_zip_titrer' => 'Pridať názvy podľa názvov súborov',

	// V
	'verifier_documents_brises' => 'Skontrolovať chýbajúce súbory',
	'verifier_documents_inutilises' => 'Skontrolovať prepojenia dokumentov',
	'vignette_supprimee' => 'Miniatúra bola odstránená'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_sk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// A
	'affichage_documents_en_cases' => 'Zobraziť v poliach',
	'affichage_documents_en_grand' => 'Zobraziť plnú veľkosť',
	'affichage_documents_en_liste_compacte' => 'Zobraziť ako kompaktný zoznam',
	'aucun_audio' => 'Žiadna zvuková stopa',
	'aucun_document' => 'Žiaden dokument',
	'aucun_file' => 'Žiaden dokument',
	'aucun_image' => 'Žiaden obrázok',
	'aucun_video' => 'Žiadne videá',
	'aucune_utilisation' => 'Tento dokument sa nepoužíva.',
	'aucune_vignette' => 'Žiadna miniatúra',

	// B
	'bouton_ajouter_document' => 'Pridať dokument',
	'bouton_ajouter_image' => 'Pridať obrázok',
	'bouton_ajouter_image_document' => 'Pridať obrázok alebo dokument',
	'bouton_attacher_document' => 'Pripojiť',
	'bouton_copier_local' => 'Skopírovať na stránku',
	'bouton_download_depuis' => 'z(o):',
	'bouton_download_local' => 'môjho počítača',
	'bouton_download_par_ftp' => 'servera',
	'bouton_download_par_mediatheque' => 'do knižnice multimédií',
	'bouton_download_sur_le_web' => 'internetu',
	'bouton_enlever_document' => 'Zrušiť prepojenie',
	'bouton_enlever_supprimer_document' => 'Odstrániť',
	'bouton_enlever_supprimer_document_confirmation' => 'Chcete odstrániť dokument?',
	'bouton_modifier_document' => 'Upraviť',
	'bouton_parcourir' => 'Prehľadať...',
	'bouton_refresh_document' => 'Obnoviť dokument',
	'bouton_remplacer_document' => 'Nahradiť tento dokument',
	'bouton_remplacer_image' => 'Nahradiť tento obrázok',
	'bouton_remplacer_image_document' => 'Nahradiť obrázkom alebo dokumentom',
	'bouton_supprimer' => 'Odstrániť',
	'bouton_supprimer_tous_orphelins' => 'Odstrániť všetky nepoužívané', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Určite chcete odstrániť @nb@ osamotených objektov?', # MODIF
	'bouton_upload' => 'Nahrať',

	// D
	'des_audios' => '@nb@ zvukových stôp',
	'des_documents' => '@nb@ dokumentov',
	'des_files' => '@nb@ súborov',
	'des_images' => '@nb@ obrázkov',
	'des_utilisations' => '@nb@ použití',
	'des_videos' => '@nb@ videosekvencií',
	'descriptif' => 'Opis', # MODIF
	'details_document' => 'Podrobnosti',
	'details_document_afficher_masquer' => 'Zobraziť/skryť podrobnosti dokumentu',
	'document_attache_succes' => 'Dokument bol úspešne pridaný',
	'document_copie_locale_succes' => 'Súbor bol úspešne skopírovaný na stránku',
	'document_installe_succes' => 'Súbor sa úspešne nahral',
	'document_vu' => 'Vložiť do textu',
	'documents' => 'Knižnica multimédií',
	'documents_brises' => 'Pokazené',
	'documents_distants' => 'Vzdialené',
	'documents_locaux' => 'Miestne',
	'documents_non_publies' => 'Nepublikované',
	'documents_orphelins' => 'Nepoužívané',
	'documents_publies' => 'Publikované',
	'documents_tous' => 'Všetky',
	'double_clic_inserer_doc' => 'Ak chcete do textu vložiť túto klávesovú skratku, dvakrát kliknite',

	// E
	'entree_dimensions' => 'Veľkosť:',
	'entree_titre_document' => 'Názov dokumentu:',
	'entree_titre_image' => 'Názov obrázka:',
	'erreur_aucun_document' => 'Tento dokument v knižnici multimédií neexistuje',
	'erreur_aucun_fichier' => 'Žiaden súbor sa nenašiel',
	'erreur_autorisation' => 'Autorizácia sa nepodarila.',
	'erreur_chemin_distant' => 'Nepodarilo sa nájsť vzdialený súbor @nom@',
	'erreur_chemin_ftp' => 'Uvedený súbor sa na serveri nenašiel',
	'erreur_copie_fichier' => 'Nepodarilo sa skopírovať súbor @nom@',
	'erreur_dossier_tmp_manquant' => 'V dočasnom priečinku chýbajú súbory na stiahnutie',
	'erreur_ecriture_fichier' => 'Chyba pri zápise súboru na disk',
	'erreur_format_fichier_image' => 'Formát súboru @nom@ nie je vhodný pre obrázok',
	'erreur_indiquez_un_fichier' => 'Uveďte súbor!',
	'erreur_insertion_document_base' => 'Dokument @fichier@ sa nepodarilo uložiť do databázy súborov',
	'erreur_objet_absent' => 'Prijaté údaje nie sú kompletné.',
	'erreur_suppression_vignette' => 'Chyba pri odstraňovaní miniatúry',
	'erreur_upload_type_interdit' => 'Sťahovanie súborov typu @nom@ nie je povolené',
	'erreur_upload_vignette' => 'Chyba pri načítavaní miniatúry @nom@',
	'erreurs' => '@nb@ chýb',
	'erreurs_voir' => 'Pozrite sa na @nb@ chýb',

	// F
	'fichier_distant' => 'Vzdialený súbor',
	'fichier_manquant' => 'Chýbajúci súbor',
	'fichier_modifie' => 'Súbor bol zmenený. Kliknite na tlačidlo Uložiť.',
	'format_date_incorrect' => 'Dátum alebo čas nie je správny',

	// I
	'icone_creer_document' => 'Pridať dokument',
	'id' => 'ID',
	'image_tourner_180' => 'Otočiť o 180°',
	'image_tourner_droite' => 'Otočiť o 90° doprava',
	'image_tourner_gauche' => 'Otočiť o 90° doľava',
	'info_dimensions_image' => 'Rozmery',
	'info_doc_max_poids' => 'Dokumenty musia mať nevyhnutne menej ako @maxi@ (tento súbor má @actuel@).',
	'info_document' => 'Dokument',
	'info_document_indisponible' => 'Tento dokument je nedostupný',
	'info_documents' => 'Dokumenty',
	'info_duree' => 'Trvanie',
	'info_gauche_numero_document' => 'DOKUMENT ČÍSLO',
	'info_hauteur' => 'Výška',
	'info_heure' => 'Čas',
	'info_illustrations' => 'Ilustrácie',
	'info_image_max_poids' => 'Obrázky musia mať nevyhnutne menej ako @maxi@ (tento súbor má @actuel@).',
	'info_image_max_taille' => 'Obrázky musia mať nevyhnutne menej ako @maxi@ (tento súbor má @actuel@).',
	'info_inclusion_directe' => 'Priame zaradenie:',
	'info_inclusion_vignette' => 'Zaradiť miniatúru:',
	'info_installer_tous_documents' => 'Nainštalovať všetky dokumenty',
	'info_largeur' => 'Šírka',
	'info_logo_max_taille' => 'Logá musia mať menej ako @maxi@ (tento súbor má @actuel@).',
	'info_mode' => 'Režim',
	'info_modifier_document' => 'Upraviť dokument',
	'info_portfolio' => 'Portfólio',
	'info_referencer_doc_distant' => 'Odkázať na dokument na internete:',
	'info_resolution_image' => 'Rozlíšenie',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Žiadna miniatúra',
	'info_statut_document' => 'Tento dokument je:',
	'info_taille' => 'Veľkosť',
	'info_telecharger' => 'Nahrať z vášho počítača:',
	'infos' => 'Technické údaje',
	'item_autoriser_selectionner_date_en_ligne' => 'Povoliť zmeniť dátum každého dokumentu',
	'item_non_autoriser_selectionner_date_en_ligne' => 'Dátum dokumentu je deň, keď bol pridaný na stránku',

	// L
	'label_activer_document_objets' => 'Aktivovať nahrávanie pre obsah:',
	'label_apercu' => 'Ukážka',
	'label_caracteristiques' => 'Funkcie',
	'label_credits' => 'Autori',
	'label_fichier' => 'Súbor',
	'label_fichier_vignette' => 'Miniatúra',
	'label_paginer_par' => 'Stránkovať po:',
	'label_parents' => 'Tento dokument je prepojený s prvkom',
	'label_refdoc_joindre' => 'Dokument číslo',
	'lien_tout_desordonner' => 'Obnoviť poradie',
	'lien_tout_desordonner_verif' => 'Poradie určené pre tento zoznam dokumentov sa zmení. Určite to chcete urobiť?',
	'lien_tout_enlever' => 'Odstrániť všetko', # MODIF
	'logo' => 'Logo',

	// M
	'media_audio' => 'Zvukové stopy',
	'media_file' => 'Ostatné',
	'media_image' => 'Obrázky',
	'media_video' => 'Videá',
	'miniature_automatique_active' => 'SPIP automaticky vytvorí miniatúru obrázka',

	// N
	'nb_documents_attache_succes' => '@nb@ dokumentov bolo pridaných',
	'nb_documents_installe_succes' => '@nb@ súborov sa úspešne nahralo',

	// O
	'objet_document' => 'Dokument',
	'objet_documents' => 'Dokumenty',
	'ordonner_ce_document' => 'Zoradiť tento dokument',

	// P
	'par_date' => 'Dátum',
	'par_hauteur' => 'Výška',
	'par_id' => 'ID',
	'par_largeur' => 'Šírka',
	'par_taille' => 'Veľkosť',
	'par_titre' => 'Názov',

	// T
	'texte_documents_joints' => 'Môžete aktivovať rozhranie na pridávanie dokumentov (súborov z práce, obrázkov
 multimédiálnych súborov, atď.) k článkom, rubrikám a inde. Na tieto súbory
 môžete potom 
v článku odkazovať alebo môžu byť zobrazené samostatne.',
	'texte_documents_joints_2' => 'Toto nastavenie nezabráni priamemu vkladaniu obrázkov do článkov alebo pripojeniu súboru priamo do textu redakčného objektu.',
	'titre_documents_joints' => 'Pripojené dokumenty',
	'titre_page_documents_edit' => 'Upraviť dokument: @titre@',
	'tous_les_medias' => 'Všetky multimédiá',
	'tout_dossier_upload' => 'Celý priečinok @upload@',
	'tout_voir' => 'Zobraziť všetko',

	// U
	'un_audio' => '1 zvuková stopa',
	'un_document' => '1 dokument',
	'un_file' => '1 súbor',
	'un_image' => '1 obrázok',
	'un_video' => '1 video',
	'une_utilisation' => '1 použitie',
	'upload_fichier_zip' => 'Súbor ZIP',
	'upload_fichier_zip_texte' => 'Súbor, ktorý sa chcete nainštalovať, je súbor ZIP.',
	'upload_fichier_zip_texte2' => 'Tento súbor môže byť:',
	'upload_info_mode_document' => 'Poslať do portfólia',
	'upload_info_mode_image' => 'Odstrániť z portfólia',
	'upload_limit' => 'Tento súbor je pre server príliš veľký, maximálna povolená veľkosť na <i>nahrávanie</i> je @max@.',
	'upload_zip_conserver' => 'Ponechať si súbor archívu aj po rozbalení jeho obsahu',
	'upload_zip_decompacter' => 'rozbalený a každý súbor, ktorý obsahuje, bude nainštalovaný na stránku. Nainštalované budú tieto súbory:',
	'upload_zip_mode_document' => 'Všetky obrázky zaradiť do portfólia',
	'upload_zip_telquel' => 'nainštalovaný tak, ako je, ako súbor ZIP,',
	'upload_zip_titrer' => 'Pridať názvy podľa názvov súborov',

	// V
	'verifier_documents_brises' => 'Skontrolovať chýbajúce súbory',
	'verifier_documents_inutilises' => 'Skontrolovať prepojenia dokumentov',
	'vignette_supprimee' => 'Miniatúra bola odstránená',
];
